/**
 * Copyright 2006-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.log.osgi.internal;

import org.osgi.framework.ServiceReference;
import org.osgi.service.log.LogService;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Basic implementation of the OSGi LogService.
 * @author Francois Fornaciari
 */
public class LoggerService implements LogService {

    /**
     * The logger.
     */
    private Log logger = LogFactory.getLog(LoggerService.class);

    /**
     * {@inheritDoc}
     */
    public void log(final int level, final String message) {
        log(level, message, null);
    }

    /**
     * {@inheritDoc}
     */
    public void log(final int level, final String message, final Throwable exception) {
        switch (level) {
        case LogService.LOG_ERROR:
            logger.error(message, exception);
            break;
        case LogService.LOG_WARNING:
            logger.warn(message, exception);
            break;
        case LogService.LOG_INFO:
            logger.info(message, exception);
            break;
        case LogService.LOG_DEBUG:
            logger.debug(message, exception);
            break;
        default:
            logger.debug(message, exception);
            break;
        }
    }

    /**
     * {@inheritDoc}
     */
    public void log(ServiceReference sr, final int level, final String message) {
        log(level, message);
    }

    /**
     * {@inheritDoc}
     */
    public void log(ServiceReference sr, final int level, final String message, final Throwable exception) {
        log(level, message, exception);
    }

}
